package com.ruoyi.dxp.service;

import java.util.List;
import com.ruoyi.dxp.domain.Notice;
import com.ruoyi.dxp.dto.NoticeSendDto;

/**
 * 通知Service接口
 * 
 * @author jy
 * @date 2023-01-06
 */
public interface INoticeService 
{
    /**
     * 查询通知
     * 
     * @param id 通知主键
     * @return 通知
     */
    public Notice selectNoticeById(Long id);

    /**
     * 查询通知列表
     * 
     * @param notice 通知
     * @return 通知集合
     */
    public List<Notice> selectNoticeList(Notice notice);

    /**
     * 新增通知
     * 
     * @param notice 通知
     * @return 结果
     */
    public int insertNotice(Notice notice);

    /**
     * 修改通知
     * 
     * @param notice 通知
     * @return 结果
     */
    public int updateNotice(Notice notice);

    /**
     * 批量删除通知
     * 
     * @param ids 需要删除的通知主键集合
     * @return 结果
     */
    public int deleteNoticeByIds(Long[] ids);

    /**
     * 删除通知信息
     * 
     * @param id 通知主键
     * @return 结果
     */
    public int deleteNoticeById(Long id);

    /**
     * 查询通知数量
     * @param notice 查询条件
     * @return 数量
     */
    public int selectNoticeCount(Notice notice);

    /**
     * 发送消息
     * @param dto 发送对象
     */
    public void sendNotice(NoticeSendDto dto);
}
